getExposureOffsetStepSize method
Gets the supported step size for exposure offset for the selected camera in EV units.
Returns 0 when the camera supports using a free value without stepping and returns -1 when exposure compensation is not supported.
Implementation
@override
Future<double> getExposureOffsetStepSize(int cameraId) async {
// iOS has no step size.
return 0;
}